@@ -1,8 +1,12 @@
 package SQL::Statement::Term;
 
-our $VERSION = '1.27_02';
+use strict;
+use warnings;
+
+our $VERSION = '1.31';
 
 use Scalar::Util qw(weaken);
+use Carp ();
 
 =pod
 
@@ -45,11 +49,10 @@ Destroys the term and undefines the weak reference to the owner.
 
 sub new
 {
-    my ( $class, $owner ) = @_;
+    my $class = $_[0];
+    my $owner = $_[1];
 
-    my %instance = ( OWNER => $owner );
-
-    my $self = bless( \%instance, $class );
+    my $self = bless( { OWNER => $owner }, $class );
     weaken( $self->{OWNER} );
 
     return $self;
@@ -61,7 +64,11 @@ sub DESTROY
     undef $self->{OWNER};
 }
 
-sub value($) { Carp::confess( sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) ); }
+sub value($)
+{
+    Carp::confess(
+              sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) );
+}
 
 package SQL::Statement::ConstantTerm;
 
@@ -121,6 +128,7 @@ package SQL::Statement::ColumnValue;
 use vars qw(@ISA);
 @ISA = qw(SQL::Statement::Term);
 
+use Carp qw(croak);
 use Params::Util qw(_INSTANCE _ARRAY0 _SCALAR);
 use Scalar::Util qw(looks_like_number);
 
